@@ -1,7 +1,7 @@
 
 ###########################################################################
-# Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
-# Please visit www.formbuilder.org for tutorials, support, and examples.
+# Copyright (c) Nate Wiger http://nateware.com. All Rights Reserved.
+# Please visit http://formbuilder.org for tutorials, support, and examples.
 ###########################################################################
 
 package CGI::FormBuilder::Messages::locale;
@@ -9,14 +9,11 @@ package CGI::FormBuilder::Messages::locale;
 use strict;
 use utf8;
 
-use CGI::FormBuilder::Util;
+use CGI::FormBuilder::Messages::default;
+use base 'CGI::FormBuilder::Messages::default';
 
-our $REVISION = do { (my $r='$Revision: 94 $') =~ s/\D+//g; $r };
-our $VERSION = '3.05';
-
-# First, create a hash of messages for this language
-# Then, change "locale" to the 2-letter country code, such as "en" or "de"
-our %MESSAGES = (
+# Define messages for this language
+__PACKAGE__->define_messages({
     lang                  => 'da_DK',
     charset               => 'utf-8',
 
@@ -66,12 +63,7 @@ Hvis du har spørgsmål, så kontakt venligst vore medarbejdere
 ved at besvare denne email.
 EOT
     mail_results_subject  => '%s indsendelsesresultat',
-);
-
-# This method should remain unchanged
-sub messages {
-    return wantarray ? %MESSAGES : \%MESSAGES;
-}
+});
 
 1;
 __END__
