@@ -1,7 +1,7 @@
 
 ###########################################################################
-# Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
-# Please visit www.formbuilder.org for tutorials, support, and examples.
+# Copyright (c) Nate Wiger http://nateware.com. All Rights Reserved.
+# Please visit http://formbuilder.org for tutorials, support, and examples.
 ###########################################################################
 
 package CGI::FormBuilder::Messages::locale;
@@ -9,11 +9,11 @@ package CGI::FormBuilder::Messages::locale;
 use strict;
 use utf8;
 
-our $REVISION = do { (my $r='$Revision: 94 $') =~ s/\D+//g; $r };
-our $VERSION = '3.05';
+use CGI::FormBuilder::Messages::default;
+use base 'CGI::FormBuilder::Messages::default';
 
 # Simply create a hash of messages for this language
-our %MESSAGES = (
+__PACKAGE__->define_messages({
     lang                  => 'de_DE',
     charset               => 'utf-8',
 
@@ -28,6 +28,12 @@ our %MESSAGES = (
     js_invalid_password   => '- Sie müssen einen gültigen Wert für das Feld "%s" angeben',
     js_invalid_textarea   => '- Sie müssen das Feld "%s" ausfüllen',
     js_invalid_file       => '- Sie müssen einen Dateinamen für das Feld "%s" angeben',
+    js_invalid_number     => '- Ungültiger nummerischer Wert für in "%s"',
+    js_invalid_date       => '- Ungültiges datum in "%s"',
+    js_invalid_url        => '- Ungültige oder fehlerhafte Url in "%s"',
+    js_invalid_email      => '- Ungültige Email-Adresse in "%s"',
+    js_invalid_time       => '- Ungültige Zeit in "%s"',
+   'js_invalid_datetime-local'    => '- Datum-Uhrzeit in "%s" ist ungültig',
     js_invalid_default    => '- Sie müssen einen gültigen Wert für das Feld "%s" angeben',
 
     js_noscript           => 'Bitte aktivieren Sie JavaScript '
@@ -65,12 +71,7 @@ Falls Sie Fragen haben, kontaktieren Sie uns bitte, indem Sie
 auf diese Email antworten.
 EOT
     mail_results_subject  => '%s Eingang',
-);
-
-# This method should remain unchanged
-sub messages {
-    return wantarray ? %MESSAGES : \%MESSAGES;
-}
+});
 
 1;
 __END__
