@@ -1,7 +1,7 @@
 
 ###########################################################################
-# Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
-# Please visit www.formbuilder.org for tutorials, support, and examples.
+# Copyright (c) Nate Wiger http://nateware.com. All Rights Reserved.
+# Please visit http://formbuilder.org for tutorials, support, and examples.
 ###########################################################################
 
 package CGI::FormBuilder::Messages::locale;
@@ -9,11 +9,11 @@ package CGI::FormBuilder::Messages::locale;
 use strict;
 use utf8;
 
-our $REVISION = do { (my $r='$Revision: 94 $') =~ s/\D+//g; $r };
-our $VERSION = '3.05';
+use CGI::FormBuilder::Messages::default;
+use base 'CGI::FormBuilder::Messages::default';
 
-# First, create a hash of messages for this language
-our %MESSAGES = (
+# Define messages for this language
+__PACKAGE__->define_messages({
     lang                  => 'no_NO',
     charset               => 'utf-8',
 
@@ -63,12 +63,7 @@ og vil bli behandlet så snart som mulig..
 
 Om du har spørsmål, ta kontakt med oss ved å svare på denne e-post.
 EOT
-);
-
-# This method should remain unchanged
-sub messages {
-    return wantarray ? %MESSAGES : \%MESSAGES;
-}
+});
 
 1;
 __END__
